package java.awt.image.renderable;

import java.awt.image.RenderedImage;
import java.util.Vector;
import java.io.Serializable;

public class ParameterBlock implements Cloneable, Serializable
{
    protected Vector<Object> sources;
    protected Vector<Object> parameters;
    
    public ParameterBlock() {
        this.sources = new Vector();
        this.parameters = new Vector();
    }
    
    public ParameterBlock(Vector<Object> sources) {
        this.sources = new Vector();
        this.parameters = new Vector();
        this.setSources(sources);
    }
    
    public ParameterBlock(Vector<Object> sources, Vector<Object> parameters) {
        this.sources = new Vector();
        this.parameters = new Vector();
        this.setSources(sources);
        this.setParameters(parameters);
    }
    
    public Object shallowClone() {
        try {
            return super.clone();
        }
        catch (Exception ex) {
            return null;
        }
    }
    
    public Object clone() {
        ParameterBlock parameterBlock;
        try {
            parameterBlock = (ParameterBlock)super.clone();
        }
        catch (Exception ex) {
            return null;
        }
        if (this.sources != null) {
            parameterBlock.setSources((Vector)this.sources.clone());
        }
        if (this.parameters != null) {
            parameterBlock.setParameters((Vector)this.parameters.clone());
            return parameterBlock;
        }
        return parameterBlock;
    }
    
    public ParameterBlock addSource(Object obj) {
        this.sources.addElement(obj);
        return this;
    }
    
    public Object getSource(int index) {
        return this.sources.elementAt(index);
    }
    
    public ParameterBlock setSource(Object obj, int index) {
        int size = this.sources.size();
        int size2 = index + 1;
        if (size < size2) {
            this.sources.setSize(size2);
        }
        this.sources.setElementAt(obj, index);
        return this;
    }
    
    public RenderedImage getRenderedSource(int index) {
        return (RenderedImage)this.sources.elementAt(index);
    }
    
    public RenderableImage getRenderableSource(int index) {
        return (RenderableImage)this.sources.elementAt(index);
    }
    
    public int getNumSources() {
        return this.sources.size();
    }
    
    public Vector<Object> getSources() {
        return this.sources;
    }
    
    public void setSources(Vector<Object> sources) {
        this.sources = sources;
    }
    
    public void removeSources() {
        this.sources = new Vector();
    }
    
    public int getNumParameters() {
        return this.parameters.size();
    }
    
    public Vector<Object> getParameters() {
        return this.parameters;
    }
    
    public void setParameters(Vector<Object> parameters) {
        this.parameters = parameters;
    }
    
    public void removeParameters() {
        this.parameters = new Vector();
    }
    
    public ParameterBlock add(Object obj) {
        this.parameters.addElement(obj);
        return this;
    }
    
    public ParameterBlock add(byte value) {
        return this.add(new Byte(value));
    }
    
    public ParameterBlock add(char value) {
        return this.add(new Character(value));
    }
    
    public ParameterBlock add(short value) {
        return this.add(new Short(value));
    }
    
    public ParameterBlock add(int value) {
        return this.add(new Integer(value));
    }
    
    public ParameterBlock add(long value) {
        return this.add(new Long(value));
    }
    
    public ParameterBlock add(float value) {
        return this.add(new Float(value));
    }
    
    public ParameterBlock add(double value) {
        return this.add(new Double(value));
    }
    
    public ParameterBlock set(Object obj, int index) {
        int size = this.parameters.size();
        int size2 = index + 1;
        if (size < size2) {
            this.parameters.setSize(size2);
        }
        this.parameters.setElementAt(obj, index);
        return this;
    }
    
    public ParameterBlock set(byte value, int n) {
        return this.set(new Byte(value), n);
    }
    
    public ParameterBlock set(char value, int n) {
        return this.set(new Character(value), n);
    }
    
    public ParameterBlock set(short value, int n) {
        return this.set(new Short(value), n);
    }
    
    public ParameterBlock set(int value, int n) {
        return this.set(new Integer(value), n);
    }
    
    public ParameterBlock set(long value, int n) {
        return this.set(new Long(value), n);
    }
    
    public ParameterBlock set(float value, int n) {
        return this.set(new Float(value), n);
    }
    
    public ParameterBlock set(double value, int n) {
        return this.set(new Double(value), n);
    }
    
    public Object getObjectParameter(int index) {
        return this.parameters.elementAt(index);
    }
    
    public byte getByteParameter(int index) {
        return (byte)this.parameters.elementAt(index);
    }
    
    public char getCharParameter(int index) {
        return (char)this.parameters.elementAt(index);
    }
    
    public short getShortParameter(int index) {
        return (short)this.parameters.elementAt(index);
    }
    
    public int getIntParameter(int index) {
        return (int)this.parameters.elementAt(index);
    }
    
    public long getLongParameter(int index) {
        return (long)this.parameters.elementAt(index);
    }
    
    public float getFloatParameter(int index) {
        return (float)this.parameters.elementAt(index);
    }
    
    public double getDoubleParameter(int index) {
        return (double)this.parameters.elementAt(index);
    }
    
    public Class[] getParamClasses() {
        int numParameters = this.getNumParameters();
        Class[] array = new Class[numParameters];
        for (int i = 0; i < numParameters; ++i) {
            Object objectParameter = this.getObjectParameter(i);
            if ((objectParameter instanceof Byte)) {
                array[i] = Byte.TYPE;
            }
            else if ((objectParameter instanceof Character)) {
                array[i] = Character.TYPE;
            }
            else if ((objectParameter instanceof Short)) {
                array[i] = Short.TYPE;
            }
            else if ((objectParameter instanceof Integer)) {
                array[i] = Integer.TYPE;
            }
            else if ((objectParameter instanceof Long)) {
                array[i] = Long.TYPE;
            }
            else if ((objectParameter instanceof Float)) {
                array[i] = Float.TYPE;
            }
            else if ((objectParameter instanceof Double)) {
                array[i] = Double.TYPE;
            }
            else {
                array[i] = objectParameter.getClass();
            }
        }
        return array;
    }
}
